==> apache-plc4x-0.6.0-source-release.zip: apache-plc4x-0.6.0/sandbox/code-gen/src/test/java/org/apache/plc4x/codegen/util/PojoFactoryTest.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.codegen.util;

import org.apache.plc4x.codegen.ast.*;

import org.junit.Test;

public class PojoFactoryTest {

    @Test
    public void createPojoJava() {
        System.out.println("Java:");
        System.out.println("----------");
        final ClassDeclaration pojo = newPojo();

        final CodeWriter writer = new CodeWriter(4);
        final JavaGenerator generator = new JavaGenerator(writer);

        pojo.write(generator);

        System.out.println(writer.getCode());
    }

    @Test
    public void createPojoPython() {
        System.out.println("Python:");
        System.out.println("----------");
        final ClassDeclaration pojo = newPojo();

        final CodeWriter writer = new CodeWriter(4);
        final PythonGenerator generator = new PythonGenerator(writer);

        pojo.write(generator);

        System.out.println(writer.getCode());
    }

    private ClassDeclaration newPojo() {
        final PojoFactory factory = new PojoFactory();
        final PojoFactory.PojoDescription description = new PojoFactory.PojoDescription("MyPojo",
            new PojoFactory.Field(Primitive.DOUBLE, "field1"),
            new PojoFactory.Field(Primitive.DOUBLE, "field2"),
            new PojoFactory.Field(Primitive.DOUBLE, "field3")
        );
        return factory.create(description);
    }
}

==> apache-plc4x-0.8.0-source-release.zip: apache-plc4x-0.8.0/sandbox/code-gen/src/test/java/org/apache/plc4x/codegen/util/PojoFactoryTest.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.codegen.util;

import org.apache.plc4x.codegen.ast.*;
import org.junit.jupiter.api.Test;

public class PojoFactoryTest {

    @Test
    public void createPojoJava() {
        System.out.println("Java:");
        System.out.println("----------");
        final ClassDeclaration pojo = newPojo();

        final CodeWriter writer = new CodeWriter(4);
        final JavaGenerator generator = new JavaGenerator(writer);

        pojo.write(generator);

        System.out.println(writer.getCode());
    }

    @Test
    public void createPojoPython() {
        System.out.println("Python:");
        System.out.println("----------");
        final ClassDeclaration pojo = newPojo();

        final CodeWriter writer = new CodeWriter(4);
        final PythonGenerator generator = new PythonGenerator(writer);

        pojo.write(generator);

        System.out.println(writer.getCode());
    }

    private ClassDeclaration newPojo() {
        final PojoFactory factory = new PojoFactory();
        final PojoFactory.PojoDescription description = new PojoFactory.PojoDescription("MyPojo",
            new PojoFactory.Field(Primitive.DOUBLE, "field1"),
            new PojoFactory.Field(Primitive.DOUBLE, "field2"),
            new PojoFactory.Field(Primitive.DOUBLE, "field3")
        );
        return factory.create(description);
    }
}
